@@ -13,4 +13,8 @@ TWITTER_CONSUMER_SECRET = base.get('TWITTER_CONSUMER_SECRET')
 TWITTER_ACCESS_TOKEN = base.get('TWITTER_ACCESS_TOKEN')
 TWITTER_ACCESS_SECRET = base.get('TWITTER_ACCESS_SECRET')
 
-BASE_URL = base.get('BASE_URL')
\ No newline at end of file
+BASE_URL = base.get('BASE_URL')
+
+ALLOW_SUBSCRIPTIONS = base.get('ALLOW_SUBSCRIPTIONS', False)
+
+FROM_EMAIL = base.get('FROM_EMAIL')
\ No newline at end of file
